@@ -1,3 +1,5 @@
+use 5.14.0;
+use warnings;
 use Dist::Iller::Standard;
 
 # PODNAME: Dist::Iller::Config::Author::CSSON
@@ -5,7 +7,7 @@ use Dist::Iller::Standard;
 
 class Dist::Iller::Config::Author::CSSON using Moose with Dist::Iller::Role::Config {
 
-    our $VERSION = '0.0103'; # VERSION
+    our $VERSION = '0.0104'; # VERSION
 
     use Path::Tiny;
     use MooseX::AttributeDocumented;
@@ -108,7 +110,7 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =head1 VERSION
 
-Version 0.0103, released 2016-01-19.
+Version 0.0104, released 2016-01-21.
 
 
 
